#!/bin/bash
#Script     	: sora_disable.sh
#Apps			: MRDEVS TOOLS
#Description	: Deshabilita el alias 'sora' para Aider
#Author			: Sora Rosero One <sora@rosero.one>
#Generated by	: Claude Code (claude-3-7-sonnet-20250219)
#Created		: 2025/03/20 12:30:00
#Modified		: 2025/03/20 12:48:05
#Version		: 1.0.0
#Use Notes		:
#   ./sora_disable.sh         -> Deshabilitar
#	No usa console.lib, ni console.es
#==============================================================================
# Derechos de Autor [2025] [Mauro Rosero P. <mauro@rosero.one>]
#==============================================================================
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Configuración inicial
# Usar DEVELOPER_DIR de base.lib
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BIN_BASE="bin"
BIN_LIBS="lib"
BIN_MESG="msg"
BIN_CFGS="config"

# Leer DEVSPATH desde el archivo de configuración o usar "devs" por defecto
if [ -f "$SCRIPT_DIR/config/devspath.dat" ]; then
  DEVSPATH=$(cat "$SCRIPT_DIR/$BIN_CFGS/devspath.dat")
else
  DEVSPATH="devs"
fi

BIN_HOME="$HOME/$DEVSPATH"
VERSION=$(cat "$BIN_HOME/$BIN_BASE/$BIN_CFGS/version")

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# Importar bibliotecas necesarias
source "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib"

# Cargar mensajes en el idioma del sistema o español por defecto
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "head"
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "developers"
title="${head_000} ${srmsg_000}"

# Verificar que 'dialog' esté instalado
if ! command -v dialog &>/dev/null; then
  echo "${npm_001}"
  exit 1
fi

# Función para eliminar alias de Sora
remove_sora_alias() {
    local alias_nombre="sora"
    local shell_config=""
    
    # Detectar el shell actual y seleccionar el archivo de configuración adecuado
    case "$SHELL" in
        */bash)
            shell_config="$HOME/.bashrc"
            ;;
        */zsh)
            shell_config="$HOME/.zshrc"
            ;;
        *)
            dialog --backtitle "${title}" --title "${head_error}" --msgbox "${srmsg_021}" 7 50
            return 1
            ;;
    esac

    # Verificar si el alias existe en el archivo de configuración
    if grep -q "alias $alias_nombre=" "$shell_config"; then
        # Eliminar el alias del archivo de configuración
        sed -i "/alias $alias_nombre=/d" "$shell_config"
        if [[ $? -eq 0 ]]; then
            dialog --backtitle "${title}" --title "${srmsg_012}" --msgbox "${srmsg_013} $shell_config" 7 60
        else
            dialog --backtitle "${title}" --title "${head_error}" --msgbox "${srmsg_020}" 7 50
            return 1
        fi
    else
        dialog --backtitle "${title}" --title "${srmsg_010}" --msgbox "${srmsg_011}" 7 50
        return 2
    fi
}

# Confirmar desactivación
dialog --backtitle "${title}" --title "${npm_031}" --yesno "${srmsg_003}" 7 50
if [[ $? -eq 0 ]]; then
  # Crear un archivo fuente para la desactivación del alias
  UNALIAS_FILE="$BIN_HOME/bin/sora_unalias.sh"
  echo '#!/bin/bash' > "$UNALIAS_FILE"
  echo 'unalias sora 2>/dev/null' >> "$UNALIAS_FILE"
  echo "echo \"${srmsg_018}\"" >> "$UNALIAS_FILE"
  chmod +x "$UNALIAS_FILE"
  
  # Ejecutar la función remove_sora_alias para el archivo de configuración permanente
  remove_sora_alias
  
  # Crear un mensaje con instrucciones para desactivar el alias en la sesión actual
  dialog --backtitle "${title}" --title "${srmsg_016}" --msgbox "${srmsg_014}\n\n${srmsg_015}\n\nsource $UNALIAS_FILE\n\n" 10 70
else
  dialog --backtitle "${title}" --title "${head_canceled}" --msgbox "${npm_008}" 6 40
  exit 1
fi

# Limpiar consola
clear
